@@ -7,6 +7,10 @@ def sql(key):
     :return:
     """
     switcher = {
+        'MySystemMetric':{
+            'sql':"SELECT `groupId` FROM loggroup where groupName LIKE '%mysystemmetric%' order  by createTime desc;",
+            'database': 'AnyRobot'
+        },
         'UserID':{'sql':'select userId from User where loginName = "admin";','database':'AnyRobot'},
         'MLID': {'sql': "select id from MLJob ;", 'database': 'AnyRobotML'},
         'entityID': {'sql': "select id from KAIEntity;", 'database': 'AnyRobot'},
