@@ -1,10 +1,10 @@
 
 class date(object):
     def getMailUser(self):
-        return 'test@aishu.tech'
+        return 'ar.test@aishu.tech'
 
     def getMailPass(self):
-        return 'niNPLwLP'
+        return 'TzELUEsRrp'
 
     def getADUser(self):
         return 'ar.test@aishu.cn'
