@@ -1,14 +1,20 @@
-
-host = ''
-port = ''
-user = ''
-password = ''
-database = 'AnyRobot'
-
 header = {
     'Accept': 'application/json, text/plain, */*',
     'Accept-Encoding': 'gzip, deflate',
     'Accept-Language': 'zh-CN,zh;q=0.9',
     'Connection': 'keep-alive',
     'Content-Type': 'application/json;charset=UTF-8'
-}
\ No newline at end of file
+}
+mysql_config = {
+    'host': '',
+    'port': '',
+    'user': '',
+    'password': '',
+    'database': ''
+
+}
+testEnv_config = {
+    'ip': '',
+    'protocol': '',
+    'port': ''
+}
